@@ -5,6 +5,7 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Tracker;
 
 /**
  * Run common work
@@ -15,7 +16,7 @@ require_once './libraries/tracking.lib.php';
 require_once 'libraries/display_create_table.lib.php';
 
 //Get some js files needed for Ajax requests
-$response = PMA_Response::getInstance();
+$response = PMA\libraries\Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('jquery/jquery.tablesorter.js');
@@ -40,21 +41,21 @@ list(
     $tooltip_truename,
     $tooltip_aliasname,
     $pos
-) = PMA_Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
+) = PMA\libraries\Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
 
 // Work to do?
 //  (here, do not use $_REQUEST['db] as it can be crafted)
 if (isset($_REQUEST['delete_tracking']) && isset($_REQUEST['table'])) {
 
-    PMA_Tracker::deleteTracking($GLOBALS['db'], $_REQUEST['table']);
-    PMA_Message::success(
+    Tracker::deleteTracking($GLOBALS['db'], $_REQUEST['table']);
+    PMA\libraries\Message::success(
         __('Tracking data deleted successfully.')
     )->display();
 
 } elseif (isset($_REQUEST['submit_create_version'])) {
 
     PMA_createTrackingForMultipleTables($_REQUEST['selected']);
-    PMA_Message::success(
+    PMA\libraries\Message::success(
         sprintf(
             __(
                 'Version %1$s was created for selected tables,'
@@ -70,9 +71,9 @@ if (isset($_REQUEST['delete_tracking']) && isset($_REQUEST['table'])) {
         if ($_REQUEST['submit_mult'] == 'delete_tracking') {
 
             foreach ($_REQUEST['selected_tbl'] as $table) {
-                PMA_Tracker::deleteTracking($GLOBALS['db'], $table);
+                Tracker::deleteTracking($GLOBALS['db'], $table);
             }
-            PMA_Message::success(
+            PMA\libraries\Message::success(
                 __('Tracking data deleted successfully.')
             )->display();
 
@@ -87,18 +88,18 @@ if (isset($_REQUEST['delete_tracking']) && isset($_REQUEST['table'])) {
             exit;
         }
     } else {
-        PMA_Message::notice(
+        PMA\libraries\Message::notice(
             __('No tables selected.')
         )->display();
     }
 }
 
 // Get tracked data about the database
-$data = PMA_Tracker::getTrackedData($_REQUEST['db'], '', '1');
+$data = Tracker::getTrackedData($_REQUEST['db'], '', '1');
 
 // No tables present and no log exist
 if ($num_tables == 0 && count($data['ddlog']) == 0) {
-    echo '<p>' . __('No tables found in database.') . '</p>' . "\n";
+    echo '<p>' , __('No tables found in database.') , '</p>' , "\n";
 
     if (empty($db_is_system_schema)) {
         echo PMA_getHtmlForCreateTable($db);
@@ -111,16 +112,19 @@ $cfgRelation = PMA_getRelationsParam();
 
 // Prepare statement to get HEAD version
 $all_tables_query = ' SELECT table_name, MAX(version) as version FROM ' .
-     PMA_Util::backquote($cfgRelation['db']) . '.' .
-     PMA_Util::backquote($cfgRelation['tracking']) .
-     ' WHERE db_name = \'' . PMA_Util::sqlAddSlashes($_REQUEST['db']) . '\' ' .
-     ' GROUP BY table_name' .
-     ' ORDER BY table_name ASC';
+    PMA\libraries\Util::backquote($cfgRelation['db']) . '.' .
+    PMA\libraries\Util::backquote($cfgRelation['tracking']) .
+    ' WHERE db_name = \'' . $GLOBALS['dbi']->escapeString($_REQUEST['db']) .
+    '\' ' .
+    ' GROUP BY table_name' .
+    ' ORDER BY table_name ASC';
 
 $all_tables_result = PMA_queryAsControlUser($all_tables_query);
 
 // If a HEAD version exists
-if (is_object($all_tables_result) && $GLOBALS['dbi']->numRows($all_tables_result) > 0) {
+if (is_object($all_tables_result)
+    && $GLOBALS['dbi']->numRows($all_tables_result) > 0
+) {
     PMA_displayTrackedTables(
         $GLOBALS['db'], $all_tables_result, $url_query, $pmaThemeImage,
         $text_dir, $cfgRelation
@@ -142,5 +146,5 @@ if (count($data['ddlog']) > 0) {
         $log .= '# ' . $entry['date'] . ' ' . $entry['username'] . "\n"
             . $entry['statement'] . "\n";
     }
-    echo PMA_Util::getMessage(__('Database Log'), $log);
+    echo PMA\libraries\Util::getMessage(__('Database Log'), $log);
 }
