@@ -19,7 +19,7 @@
  * and re-import after switching to our session.
  *
  * However, since https://github.com/phpmyadmin/phpmyadmin/commit/063a2d99
- * we have deactivated this feature, so the corresponding code is now 
+ * we have deactivated this feature, so the corresponding code is now
  * commented out.
  */
 
@@ -34,7 +34,8 @@ if (version_compare(PHP_VERSION, '5.4.0', '>=')
     session_start();
     foreach ($_SESSION as $key => $value) {
         // only copy session-prefixed data
-        if (substr($key, 0, strlen(UPLOAD_PREFIX)) == UPLOAD_PREFIX) {
+        if (mb_substr($key, 0, mb_strlen(UPLOAD_PREFIX))
+            == UPLOAD_PREFIX) {
             $sessionupload[$key] = $value;
         }
     }
@@ -51,6 +52,11 @@ define('PMA_MINIMUM_COMMON', 1);
 
 require_once 'libraries/common.inc.php';
 require_once 'libraries/display_import_ajax.lib.php';
+list(
+    $SESSION_KEY,
+    $upload_id,
+    $plugins
+) = PMA_uploadProgressSetup();
 
 /*
 if (defined('SESSIONUPLOAD')) {
@@ -63,7 +69,8 @@ if (defined('SESSIONUPLOAD')) {
 
     // remove session upload data that are not set anymore
     foreach ($_SESSION as $key => $value) {
-        if (substr($key, 0, strlen(UPLOAD_PREFIX)) == UPLOAD_PREFIX
+        if (mb_substr($key, 0, mb_strlen(UPLOAD_PREFIX))
+            == UPLOAD_PREFIX
             && ! isset($sessionupload[$key])
         ) {
             unset($_SESSION[$key]);
@@ -72,30 +79,43 @@ if (defined('SESSIONUPLOAD')) {
 }
  */
 
-// AJAX requests can't be cached!
-PMA_noCacheHeader();
-
 // $_GET["message"] is used for asking for an import message
 if (isset($_GET["message"]) && $_GET["message"]) {
 
+    // AJAX requests can't be cached!
+    PMA_noCacheHeader();
+
     header('Content-type: text/html');
 
     // wait 0.3 sec before we check for $_SESSION variable,
     // which is set inside import.php
     usleep(300000);
 
+    $maximumTime = ini_get('max_execution_time');
+    $timestamp = time();
     // wait until message is available
     while ($_SESSION['Import_message']['message'] == null) {
+        // close session before sleeping
+        session_write_close();
+        // sleep
         usleep(250000); // 0.25 sec
+        // reopen session
+        session_start();
+
+        if ((time() - $timestamp) > $maximumTime) {
+            $_SESSION['Import_message']['message'] = PMA\libraries\Message::error(
+                __('Could not load the progress of the import.')
+            )->getDisplay();
+            break;
+        }
     }
 
     echo $_SESSION['Import_message']['message'];
-    echo '<fieldset class="tblFooters">' . "\n";
-    echo '    [ <a href="' . $_SESSION['Import_message']['go_back_url']
-        . '">' . __('Back') . '</a> ]' . "\n";
-    echo '</fieldset>' . "\n";
+    echo '<fieldset class="tblFooters">' , "\n";
+    echo '    [ <a href="' , $_SESSION['Import_message']['go_back_url']
+        . '">' , __('Back') , '</a> ]' , "\n";
+    echo '</fieldset>' , "\n";
 
 } else {
     PMA_importAjaxStatus($_GET["id"]);
 }
-?>
