@@ -3,6 +3,32 @@
  * Functions used in configuration forms and on user preferences pages
  */
 
+/**
+ * checks whether browser supports web storage
+ *
+ * @param type the type of storage i.e. localStorage or sessionStorage
+ *
+ * @returns bool
+ */
+function isStorageSupported(type, warn)
+{
+    try {
+        window[type].setItem('PMATest', 'test');
+        // Check whether key-value pair was set successfully
+        if (window[type].getItem('PMATest') === 'test') {
+            // Supported, remove test variable from storage
+            window[type].removeItem('PMATest');
+            return true;
+        }
+    } catch(error) {
+        // Not supported
+        if (warn) {
+            PMA_ajaxShowMessage(PMA_messages.strNoLocalStorage, false);
+        }
+    }
+    return false;
+}
+
 /**
  * Unbind all event handlers before tearing down a page
  */
@@ -564,8 +590,9 @@ function setTab(tab_id)
         }
         $this.find('li').removeClass('active').find('a[href=#' + tab_id + ']').parent().addClass('active');
         $this.parent().find('div.tabs_contents fieldset').hide().filter('#' + tab_id).show();
-        location.hash = 'tab_' + tab_id;
-        $this.parent().find('input[name=tab_hash]').val(location.hash);
+        var hashValue = 'tab_' + tab_id;
+        location.hash = hashValue;
+        $this.parent().find('input[name=tab_hash]').val(hashValue);
     });
 }
 
@@ -600,8 +627,12 @@ AJAX.registerOnload('config.js', function () {
     var tab_check_fnc = function () {
         if (location.hash != prev_hash) {
             prev_hash = location.hash;
-            if (location.hash.match(/^#tab_.+/) && $('#' + location.hash.substr(5)).length) {
-                setTab(location.hash.substr(5));
+            if (prev_hash.match(/^#tab_[a-zA-Z0-9_]+$/)) {
+                // session ID is sometimes appended here
+                var hash = prev_hash.substr(5).split('&')[0];
+                if ($('#' + hash).length) {
+                    setTab(hash);
+                }
             }
         }
     };
@@ -711,7 +742,7 @@ AJAX.registerOnload('config.js', function () {
         });
 
     // detect localStorage state
-    var ls_supported = isStorageSupported('localStorage');
+    var ls_supported = isStorageSupported('localStorage', true);
     var ls_exists = ls_supported ? (window.localStorage.config || false) : false;
     $('div.localStorage-' + (ls_supported ? 'un' : '') + 'supported').hide();
     $('div.localStorage-' + (ls_exists ? 'empty' : 'exists')).hide();
@@ -824,7 +855,7 @@ function offerPrefsAutoimport()
             $.post('index.php', {
                 token: $cnt.find('input[name=token]').val(),
                 prefs_autoload: 'hide'
-            });
+            }, null, 'html');
             return;
         }
         $cnt.find('input[name=json]').val(window.localStorage.config);
