@@ -540,6 +540,16 @@ function toggle_table_select(row) {
     }
 }
 
+function handleAddProcCheckbox() {
+    if ($('#table_structure_all').is(':checked') === true
+        && $('#table_data_all').is(':checked') === true
+    ) {
+        $('#checkbox_sql_procedure_function').prop('checked', true);
+    } else {
+        $('#checkbox_sql_procedure_function').prop('checked', false);
+    }
+}
+
 AJAX.registerOnload('export.js', function () {
     /**
      * For SQL plugin, if "CREATE TABLE options" is checked/unchecked, check/uncheck each of its sub-options
@@ -579,26 +589,31 @@ AJAX.registerOnload('export.js', function () {
     $('input[name="table_select[]"]').on('change', function() {
         toggle_table_select($(this).closest('tr'));
         check_table_select_all();
+        handleAddProcCheckbox();
     });
 
     $('input[name="table_structure[]"]').on('change', function() {
         check_table_selected($(this).closest('tr'));
         check_table_select_all();
+        handleAddProcCheckbox();
     });
 
     $('input[name="table_data[]"]').on('change', function() {
         check_table_selected($(this).closest('tr'));
         check_table_select_all();
+        handleAddProcCheckbox();
     });
 
     $('#table_structure_all').on('change', function() {
         toggle_table_select_all_str();
         check_selected_tables();
+        handleAddProcCheckbox();
     });
 
     $('#table_data_all').on('change', function() {
         toggle_table_select_all_data();
         check_selected_tables();
+        handleAddProcCheckbox();
     });
 
     if ($("input[name='export_type']").val() == 'database') {
@@ -805,6 +820,8 @@ AJAX.registerOnload('export.js', function () {
     toggle_quick_or_custom();
     toggle_structure_data_opts();
     toggle_sql_include_comments();
+    check_table_select_all();
+    handleAddProcCheckbox();
 
     /**
      * Initially disables the "Dump some row(s)" sub-options
