@@ -82,7 +82,7 @@ function goTo2NFStep1() {
             $("#mainContent #extra").html(data.extra);
             $("#mainContent #newCols").html('');
             if (data.subText !== '') {
-                $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strDone + '" onclick="processDependencies(\'' + data.primary_key + '\');">');
+                $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strDone + '" onclick="processDependencies(\'' + escapeJsString(escapeHtml(data.primary_key)) + '\');">');
             } else {
                 if (normalizeto === '3nf') {
                     $("#mainContent #newCols").html(PMA_messages.strToNextStep);
@@ -128,7 +128,7 @@ function goToStep4()
             $("#mainContent #newCols").html('');
             $('.tblFooters').html('');
             for(var pk in primary_key) {
-                $("#extra input[value='" + primary_key[pk] + "']").attr("disabled","disabled");
+                $("#extra input[value='" + escapeJsString(primary_key[pk]) + "']").attr("disabled","disabled");
             }
         }
     );
@@ -153,7 +153,7 @@ function goToStep3()
             $('.tblFooters').html('');
             primary_key = $.parseJSON(data.primary_key);
             for(var pk in primary_key) {
-                $("#extra input[value='" + primary_key[pk] + "']").attr("disabled","disabled");
+                $("#extra input[value='" + escapeJsString(primary_key[pk]) + "']").attr("disabled","disabled");
             }
         }
     );
@@ -209,7 +209,7 @@ function goTo2NFFinish(pd)
             "newTablesName":JSON.stringify(tables),
             "createNewTables2NF":1};
     $.ajax({
-            type: "GET",
+            type: "POST",
             url: "normalization.php",
             data: datastring,
             async:false,
@@ -254,7 +254,7 @@ function goTo3NFFinish(newTables)
             "newTables":JSON.stringify(newTables),
             "createNewTables3NF":1};
     $.ajax({
-            type: "GET",
+            type: "POST",
             url: "normalization.php",
             data: datastring,
             async:false,
@@ -526,7 +526,7 @@ AJAX.registerOnload('normalization.js', function() {
         datastring += "&ajax_request=1&do_save_data=1&field_where=last";
         $.post("tbl_addfield.php", datastring, function(data) {
             if (data.success) {
-                $.get(
+                $.post(
                     "sql.php",
                     {
                         "token": PMA_commonParams.get('token'),
@@ -604,7 +604,7 @@ AJAX.registerOnload('normalization.js', function() {
             dropQuery += 'DROP `' + $(this).val() + '`, ';
         });
         dropQuery = dropQuery.slice(0, -2);
-        $.get(
+        $.post(
             "sql.php",
             {
                 "token": PMA_commonParams.get('token'),
@@ -638,7 +638,7 @@ AJAX.registerOnload('normalization.js', function() {
                 '</ol>';
             $("#newCols").html(confirmStr);
             $('.tblFooters').html('<input type="submit" value="' + PMA_messages.strCancel + '" onclick="$(\'#newCols\').html(\'\');$(\'#extra input[type=checkbox]\').removeAttr(\'checked\')"/>' +
-                '<input type="submit" value="' + PMA_messages.strGo + '" onclick="moveRepeatingGroup(\'' + repeatingCols + '\')"/>');
+                '<input type="submit" value="' + PMA_messages.strGo + '" onclick="moveRepeatingGroup(\'' + escapeJsString(escapeHtml(repeatingCols)) + '\')"/>');
         }
     });
     $("#mainContent p").on("click", "#createPrimaryKey", function(event) {
