@@ -15,17 +15,11 @@
  */
 OpenLayers.Lang["ar"] = OpenLayers.Util.applyDefaults({
 
-    'permalink': "وصلة دائمة",
+    'Permalink': "وصلة دائمة",
 
-    'baseLayer': "الطبقة الاساسية",
+    'Base Layer': "الطبقة الاساسية",
 
-    'readNotImplemented': "القراءة غير محققة.",
-
-    'writeNotImplemented': "الكتابة غير محققة",
-
-    'errorLoadingGML': "خطأ عند تحميل الملف جي ام ال ${url}",
-
-    'scale': "النسبة = 1 : ${scaleDenom}",
+    'Scale = 1 : ${scaleDenom}': "النسبة = 1 : ${scaleDenom}",
 
     'W': "غ",
 
