@@ -15,6 +15,8 @@ var RTE = {
      */
     object: function (type) {
         $.extend(this, RTE.COMMON);
+        this.editorType = type;
+
         switch (type) {
         case 'routine':
             $.extend(this, RTE.ROUTINE);
@@ -58,6 +60,10 @@ RTE.COMMON = {
      *                    the jQueryUI dialog buttons
      */
     buttonOptions: {},
+    /**
+     * @var editorType Type of the editor
+     */
+    editorType: null,
     /**
      * Validate editor form fields.
      */
@@ -122,6 +128,11 @@ RTE.COMMON = {
             var count = export_anchors.length;
             var returnCount = 0;
 
+            // No routine is exportable (due to privilege issues)
+            if (count === 0) {
+                PMA_ajaxShowMessage(PMA_messages.NoExportable);
+            }
+
             export_anchors.each(function () {
                 $.get($(this).attr('href'), {'ajax_request': true}, function (data) {
                     returnCount++;
@@ -143,6 +154,7 @@ RTE.COMMON = {
         } else {
             $.get($this.attr('href'), {'ajax_request': true}, showExport);
         }
+        PMA_ajaxRemoveMessage($msg);
 
         function showExport(data) {
             if (data.success === true) {
@@ -360,7 +372,9 @@ RTE.COMMON = {
                  *                 the Definition textarea.
                  */
                 var $elm = $('textarea[name=item_definition]').last();
-                that.syntaxHiglighter = PMA_getSQLEditor($elm);
+                var linterOptions = {};
+                linterOptions[that.editorType + '_editor'] = true;
+                that.syntaxHiglighter = PMA_getSQLEditor($elm, {}, null, linterOptions);
 
                 // Execute item-specific code
                 that.postDialogShow(data);
@@ -388,7 +402,7 @@ RTE.COMMON = {
              *          the AJAX message shown to the user
              */
             var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-            $.get(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+            $.post(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
                 if (data.success === true) {
                     /**
                      * @var $table Object containing reference
@@ -437,7 +451,7 @@ RTE.COMMON = {
                 } else {
                     PMA_ajaxShowMessage(data.error, false);
                 }
-            }); // end $.get()
+            }); // end $.post()
         }); // end $.PMA_confirm()
     },
 
@@ -462,7 +476,7 @@ RTE.COMMON = {
                  * @var $curr_row Object containing reference to the current row
                  */
                 var $curr_row = $anchor.parents('tr');
-                $.get($anchor.attr('href'), {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+                $.post($anchor.attr('href'), {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
                     returnCount++;
                     if (data.success === true) {
                         /**
@@ -519,7 +533,7 @@ RTE.COMMON = {
                             PMA_reloadNavigation();
                         }
                     }
-                }); // end $.get()
+                }); // end $.post()
             }); // end drop_anchors.each()
         }); // end $.PMA_confirm()
     }
@@ -591,6 +605,48 @@ RTE.ROUTINE = {
             $('table.rte_table').last().find('select[name=item_returnopts_text]'),
             $('table.rte_table').last().find('select[name=item_returnopts_num]')
         );
+        // Allow changing parameter order
+        $('.routine_params_table tbody').sortable({
+            containment: '.routine_params_table tbody',
+            handle: '.dragHandle',
+            stop: function(event, ui) {
+                that.reindexParameters();
+            },
+        });
+    },
+    /**
+     * Reindexes the parameters after dropping a parameter or reordering parameters
+     */
+    reindexParameters: function () {
+        /**
+         * @var index Counter used for reindexing the input
+         *            fields in the routine parameters table
+         */
+        var index = 0;
+        $('table.routine_params_table tbody').find('tr').each(function () {
+            $(this).find(':input').each(function () {
+                /**
+                 * @var inputname The value of the name attribute of
+                 *                the input field being reindexed
+                 */
+                var inputname = $(this).attr('name');
+                if (inputname.substr(0, 14) === 'item_param_dir') {
+                    $(this).attr('name', inputname.substr(0, 14) + '[' + index + ']');
+                } else if (inputname.substr(0, 15) === 'item_param_name') {
+                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
+                } else if (inputname.substr(0, 15) === 'item_param_type') {
+                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
+                } else if (inputname.substr(0, 17) === 'item_param_length') {
+                    $(this).attr('name', inputname.substr(0, 17) + '[' + index + ']');
+                    $(this).attr('id', 'item_param_length_' + index);
+                } else if (inputname.substr(0, 20) === 'item_param_opts_text') {
+                    $(this).attr('name', inputname.substr(0, 20) + '[' + index + ']');
+                } else if (inputname.substr(0, 19) === 'item_param_opts_num') {
+                    $(this).attr('name', inputname.substr(0, 19) + '[' + index + ']');
+                }
+            });
+            index++;
+        });
     },
     /**
      * Overriding the validateCustom() function defined in common.js
@@ -736,8 +792,6 @@ RTE.ROUTINE = {
         // Process for parameter length
         switch ($type.val()) {
         case 'DATE':
-        case 'DATETIME':
-        case 'TIME':
         case 'TINYBLOB':
         case 'TINYTEXT':
         case 'BLOB':
@@ -768,7 +822,7 @@ RTE.ROUTINE = {
          *          the AJAX message shown to the user
          */
         var $msg = PMA_ajaxShowMessage();
-        $.get($this.attr('href'), {'ajax_request': true}, function (data) {
+        $.post($this.attr('href'), {'ajax_request': true}, function (data) {
             if (data.success === true) {
                 PMA_ajaxRemoveMessage($msg);
                 // If 'data.dialog' is true we show a dialog with a form
@@ -852,7 +906,7 @@ RTE.ROUTINE = {
             } else {
                 PMA_ajaxShowMessage(data.error, false);
             }
-        }); // end $.get()
+        }); // end $.post()
     }
 };
 
@@ -1014,34 +1068,6 @@ $(function () {
         $(this).parent().parent().remove();
         // After removing a parameter, the indices of the name attributes in
         // the input fields lose the correct order and need to be reordered.
-        /**
-         * @var index Counter used for reindexing the input
-         *            fields in the routine parameters table
-         */
-        var index = 0;
-        $(this).closest('div.ui-dialog').find('table.routine_params_table').find('tr').has('td').each(function () {
-            $(this).find(':input').each(function () {
-                /**
-                 * @var inputname The value of the name attribute of
-                 *                the input field being reindexed
-                 */
-                var inputname = $(this).attr('name');
-                if (inputname.substr(0, 14) === 'item_param_dir') {
-                    $(this).attr('name', inputname.substr(0, 14) + '[' + index + ']');
-                } else if (inputname.substr(0, 15) === 'item_param_name') {
-                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
-                } else if (inputname.substr(0, 15) === 'item_param_type') {
-                    $(this).attr('name', inputname.substr(0, 15) + '[' + index + ']');
-                } else if (inputname.substr(0, 17) === 'item_param_length') {
-                    $(this).attr('name', inputname.substr(0, 17) + '[' + index + ']');
-                    $(this).attr('id', 'item_param_length_' + index);
-                } else if (inputname.substr(0, 20) === 'item_param_opts_text') {
-                    $(this).attr('name', inputname.substr(0, 20) + '[' + index + ']');
-                } else if (inputname.substr(0, 19) === 'item_param_opts_num') {
-                    $(this).attr('name', inputname.substr(0, 19) + '[' + index + ']');
-                }
-            });
-            index++;
-        });
+        RTE.ROUTINE.reindexParameters();
     }); // end $(document).on()
 }); // end of $()
