@@ -7,6 +7,8 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Message;
+
 if (! defined('PHPMYADMIN')) {
     exit;
 }
@@ -15,8 +17,6 @@ if (! defined('PHPMYADMIN')) {
  * String handling (security)
  */
 require_once 'libraries/string.lib.php';
-require_once 'libraries/String.class.php';
-$PMA_String = new PMA_String();
 
 /**
  * checks given $var and returns it if valid, or $default of not valid
@@ -28,15 +28,15 @@ $PMA_String = new PMA_String();
  * echo PMA_ifSetOr($_REQUEST['db'], ''); // ''
  * // $_REQUEST['sql_query'] not set
  * echo PMA_ifSetOr($_REQUEST['sql_query']); // null
- * // $cfg['ForceSSL'] not set
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'boolean'); // false
- * echo PMA_ifSetOr($cfg['ForceSSL']); // null
- * // $cfg['ForceSSL'] set to 1
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'boolean'); // false
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'similar'); // 1
- * echo PMA_ifSetOr($cfg['ForceSSL'], false); // 1
- * // $cfg['ForceSSL'] set to true
- * echo PMA_ifSetOr($cfg['ForceSSL'], false, 'boolean'); // true
+ * // $cfg['EnableFoo'] not set
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'boolean'); // false
+ * echo PMA_ifSetOr($cfg['EnableFoo']); // null
+ * // $cfg['EnableFoo'] set to 1
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'boolean'); // false
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'similar'); // 1
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false); // 1
+ * // $cfg['EnableFoo'] set to true
+ * echo PMA_ifSetOr($cfg['EnableFoo'], false, 'boolean'); // true
  * </code>
  *
  * @param mixed &$var    param to check
@@ -96,7 +96,7 @@ function PMA_ifSetOr(&$var, $default = null, $type = 'similar')
  * @return boolean whether valid or not
  *
  * @todo add some more var types like hex, bin, ...?
- * @see     http://php.net/gettype
+ * @see     https://php.net/gettype
  */
 function PMA_isValid(&$var, $type = 'length', $compare = null)
 {
@@ -163,7 +163,7 @@ function PMA_isValid(&$var, $type = 'length', $compare = null)
     if ($type === 'length' || $type === 'scalar') {
         $is_scalar = is_scalar($var);
         if ($is_scalar && $type === 'length') {
-            return (bool) /*overload*/mb_strlen($var);
+            return (bool) mb_strlen($var);
         }
         return $is_scalar;
     }
@@ -206,13 +206,10 @@ function PMA_securePath($path)
  *
  * @param string       $error_message  the error message or named error message
  * @param string|array $message_args   arguments applied to $error_message
- * @param boolean      $delete_session whether to delete session cookie
  *
  * @return void
  */
-function PMA_fatalError(
-    $error_message, $message_args = null, $delete_session = true
-) {
+function PMA_fatalError($error_message, $message_args = null) {
     /* Use format string if applicable */
     if (is_string($message_args)) {
         $error_message = sprintf($error_message, $message_args);
@@ -220,10 +217,10 @@ function PMA_fatalError(
         $error_message = vsprintf($error_message, $message_args);
     }
 
-    if ($GLOBALS['is_ajax_request']) {
-        $response = PMA_Response::getInstance();
-        $response->isSuccess(false);
-        $response->addJSON('message', PMA_Message::error($error_message));
+    if (! empty($GLOBALS['is_ajax_request']) && $GLOBALS['is_ajax_request']) {
+        $response = PMA\libraries\Response::getInstance();
+        $response->setRequestStatus(false);
+        $response->addJSON('message', PMA\libraries\Message::error($error_message));
     } else {
         $error_message = strtr($error_message, array('<br />' => '[br]'));
 
@@ -246,16 +243,8 @@ function PMA_fatalError(
         } else {
             $error_header = 'Error';
         }
-        $lang = $GLOBALS['available_languages'][$GLOBALS['lang']][1];
-        $dir = $GLOBALS['text_dir'];
-
-        // on fatal errors it cannot hurt to always delete the current session
-        if ($delete_session
-            && isset($GLOBALS['session_name'])
-            && isset($_COOKIE[$GLOBALS['session_name']])
-        ) {
-            $GLOBALS['PMA_Config']->removeCookie($GLOBALS['session_name']);
-        }
+        $lang = isset($GLOBALS['lang']) ? $GLOBALS['lang'] : 'en';
+        $dir = isset($GLOBALS['text_dir']) ? $GLOBALS['text_dir'] : 'ltr';
 
         // Displays the error message
         include './libraries/error.inc.php';
@@ -286,7 +275,7 @@ function PMA_getPHPDocLink($target)
         $lang = $GLOBALS['lang'];
     }
 
-    return PMA_linkURL('http://php.net/manual/' . $lang . '/' . $target);
+    return PMA_linkURL('https://php.net/manual/' . $lang . '/' . $target);
 }
 
 /**
@@ -341,8 +330,8 @@ function PMA_warnMissingExtension($extension, $fatal = false, $extra = '')
 function PMA_getTableCount($db)
 {
     $tables = $GLOBALS['dbi']->tryQuery(
-        'SHOW TABLES FROM ' . PMA_Util::backquote($db) . ';',
-        null, PMA_DatabaseInterface::QUERY_STORE
+        'SHOW TABLES FROM ' . PMA\libraries\Util::backquote($db) . ';',
+        null, PMA\libraries\DatabaseInterface::QUERY_STORE
     );
     if ($tables) {
         $num_tables = $GLOBALS['dbi']->numRows($tables);
@@ -356,7 +345,7 @@ function PMA_getTableCount($db)
 
 /**
  * Converts numbers like 10M into bytes
- * Used with permission from Moodle (http://moodle.org) by Martin Dougiamas
+ * Used with permission from Moodle (https://moodle.org) by Martin Dougiamas
  * (renamed with PMA prefix to avoid double definition when embedded
  * in Moodle)
  *
@@ -402,104 +391,6 @@ function PMA_getRealSize($size = 0)
     return $size;
 } // end function PMA_getRealSize()
 
-/**
- * merges array recursive like array_merge_recursive() but keyed-values are
- * always overwritten.
- *
- * array PMA_arrayMergeRecursive(array $array1[, array $array2[, array ...]])
- *
- * @return array   merged array
- *
- * @see     http://php.net/array_merge
- * @see     http://php.net/array_merge_recursive
- */
-function PMA_arrayMergeRecursive()
-{
-    switch(func_num_args()) {
-    case 0 :
-        return false;
-    case 1 :
-        // when does that happen?
-        return func_get_arg(0);
-    case 2 :
-        $args = func_get_args();
-        if (! is_array($args[0]) || ! is_array($args[1])) {
-            return $args[1];
-        }
-        foreach ($args[1] as $key2 => $value2) {
-            if (isset($args[0][$key2]) && !is_int($key2)) {
-                $args[0][$key2] = PMA_arrayMergeRecursive(
-                    $args[0][$key2], $value2
-                );
-            } else {
-                // we erase the parent array, otherwise we cannot override
-                // a directive that contains array elements, like this:
-                // (in config.default.php)
-                // $cfg['ForeignKeyDropdownOrder']= array('id-content','content-id');
-                // (in config.inc.php)
-                // $cfg['ForeignKeyDropdownOrder']= array('content-id');
-                if (is_int($key2) && $key2 == 0) {
-                    unset($args[0]);
-                }
-                $args[0][$key2] = $value2;
-            }
-        }
-        return $args[0];
-    default :
-        $args = func_get_args();
-        $args[1] = PMA_arrayMergeRecursive($args[0], $args[1]);
-        array_shift($args);
-        return call_user_func_array('PMA_arrayMergeRecursive', $args);
-    }
-}
-
-/**
- * calls $function for every element in $array recursively
- *
- * this function is protected against deep recursion attack CVE-2006-1549,
- * 1000 seems to be more than enough
- *
- * @param array    &$array             array to walk
- * @param callable $function           function to call for every array element
- * @param bool     $apply_to_keys_also whether to call the function for the keys also
- *
- * @return void
- *
- * @see http://www.php-security.org/MOPB/MOPB-02-2007.html
- * @see http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2006-1549
- */
-function PMA_arrayWalkRecursive(&$array, $function, $apply_to_keys_also = false)
-{
-    static $recursive_counter = 0;
-    $walked_keys = array();
-
-    if (++$recursive_counter > 1000) {
-        PMA_fatalError(__('possible deep recursion attack'));
-    }
-    foreach ($array as $key => $value) {
-        if (isset($walked_keys[$key])) {
-            continue;
-        }
-        $walked_keys[$key] = true;
-
-        if (is_array($value)) {
-            PMA_arrayWalkRecursive($array[$key], $function, $apply_to_keys_also);
-        } else {
-            $array[$key] = $function($value);
-        }
-
-        if ($apply_to_keys_also && is_string($key)) {
-            $new_key = $function($key);
-            if ($new_key != $key) {
-                $array[$new_key] = $array[$key];
-                unset($array[$key]);
-                $walked_keys[$new_key] = true;
-            }
-        }
-    }
-    $recursive_counter--;
-}
-
 /**
  * boolean phpMyAdmin.PMA_checkPageValidity(string &$page, array $whitelist)
  *
@@ -521,20 +412,20 @@ function PMA_checkPageValidity(&$page, $whitelist)
         return true;
     }
 
-    $_page = /*overload*/mb_substr(
+    $_page = mb_substr(
         $page,
         0,
-        /*overload*/mb_strpos($page . '?', '?')
+        mb_strpos($page . '?', '?')
     );
     if (in_array($_page, $whitelist)) {
         return true;
     }
 
     $_page = urldecode($page);
-    $_page = /*overload*/mb_substr(
+    $_page = mb_substr(
         $_page,
         0,
-        /*overload*/mb_strpos($_page . '?', '?')
+        mb_strpos($_page . '?', '?')
     );
     if (in_array($_page, $whitelist)) {
         return true;
@@ -582,39 +473,32 @@ function PMA_getenv($var_name)
  * @param string $uri         the header to send
  * @param bool   $use_refresh whether to use Refresh: header when running on IIS
  *
- * @return boolean  always true
+ * @return void
  */
 function PMA_sendHeaderLocation($uri, $use_refresh = false)
 {
-    if (PMA_IS_IIS && /*overload*/mb_strlen($uri) > 600) {
+    if (PMA_IS_IIS && mb_strlen($uri) > 600) {
         include_once './libraries/js_escape.lib.php';
-        PMA_Response::getInstance()->disable();
+        PMA\libraries\Response::getInstance()->disable();
 
-        include_once './libraries/Template.class.php';
-
-        echo PMA\Template::get('header_location')
+        echo PMA\libraries\Template::get('header_location')
             ->render(array('uri' => $uri));
 
         return;
     }
 
-    if (SID) {
-        if (/*overload*/mb_strpos($uri, '?') === false) {
-            header('Location: ' . $uri . '?' . SID);
-        } else {
-            $separator = PMA_URL_getArgSeparator();
-            header('Location: ' . $uri . $separator . SID);
-        }
-        return;
+    /*
+     * Avoid relative path redirect problems in case user entered URL
+     * like /phpmyadmin/index.php/ which some web servers happily accept.
+     */
+    if ($uri[0] == '.') {
+        $uri = $GLOBALS['PMA_Config']->getRootPath() . substr($uri, 2);
     }
 
+    $response = PMA\libraries\Response::getInstance();
+
     session_write_close();
-    if (headers_sent()) {
-        if (function_exists('debug_print_backtrace')) {
-            echo '<pre>';
-            debug_print_backtrace();
-            echo '</pre>';
-        }
+    if ($response->headersSent()) {
         trigger_error(
             'PMA_sendHeaderLocation called when headers are already sent!',
             E_USER_ERROR
@@ -624,9 +508,9 @@ function PMA_sendHeaderLocation($uri, $use_refresh = false)
     // results in a blank page
     // but we need it when coming from the cookie login panel)
     if (PMA_IS_IIS && $use_refresh) {
-        header('Refresh: 0; ' . $uri);
+        $response->header('Refresh: 0; ' . $uri);
     } else {
-        header('Location: ' . $uri);
+        $response->header('Location: ' . $uri);
     }
 }
 
@@ -661,7 +545,7 @@ function PMA_noCacheHeader()
         return;
     }
     // rfc2616 - Section 14.21
-    header('Expires: ' . date(DATE_RFC1123));
+    header('Expires: ' . gmdate(DATE_RFC1123));
     // HTTP/1.1
     header(
         'Cache-Control: no-store, no-cache, must-revalidate,'
@@ -684,7 +568,7 @@ function PMA_noCacheHeader()
     // test case: exporting a database into a .gz file with Safari
     // would produce files not having the current time
     // (added this header for Safari but should not harm other browsers)
-    header('Last-Modified: ' . date(DATE_RFC1123));
+    header('Last-Modified: ' . gmdate(DATE_RFC1123));
 }
 
 
@@ -822,7 +706,7 @@ function PMA_arrayRemove($path, &$array)
  */
 function PMA_linkURL($url)
 {
-    if (!preg_match('#^https?://#', $url) || defined('PMA_SETUP')) {
+    if (!preg_match('#^https?://#', $url)) {
         return $url;
     }
 
@@ -837,7 +721,12 @@ function PMA_linkURL($url)
     $arr = parse_url($url);
     parse_str($arr["query"], $vars);
     $query = http_build_query(array("url" => $vars["url"]));
-    $url = './url.php?' . $query;
+
+    if (defined('PMA_SETUP')) {
+        $url = '../url.php?' . $query;
+    } else {
+        $url = './url.php?' . $query;
+    }
 
     return $url;
 }
@@ -854,32 +743,43 @@ function PMA_linkURL($url)
 function PMA_isAllowedDomain($url)
 {
     $arr = parse_url($url);
+    // We need host to be set
+    if (! isset($arr['host']) || strlen($arr['host']) == 0) {
+        return false;
+    }
+    // We do not want these to be present
+    $blocked = array('user', 'pass', 'port');
+    foreach ($blocked as $part) {
+        if (isset($arr[$part]) && strlen($arr[$part]) != 0) {
+            return false;
+        }
+    }
     $domain = $arr["host"];
     $domainWhiteList = array(
         /* Include current domain */
         $_SERVER['SERVER_NAME'],
         /* phpMyAdmin domains */
-        'wiki.phpmyadmin.net', 'www.phpmyadmin.net', 'phpmyadmin.net',
+        'wiki.phpmyadmin.net',
+        'www.phpmyadmin.net',
+        'phpmyadmin.net',
+        'demo.phpmyadmin.net',
         'docs.phpmyadmin.net',
         /* mysql.com domains */
         'dev.mysql.com','bugs.mysql.com',
-        /* drizzle.org domains */
-        'www.drizzle.org',
         /* mariadb domains */
-        'mariadb.org',
+        'mariadb.org', 'mariadb.com',
         /* php.net domains */
         'php.net',
+        /* sourceforge.net domain */
+        'sourceforge.net',
         /* Github domains*/
         'github.com','www.github.com',
-        /* Following are doubtful ones. */
-        'www.primebase.com',
-        'pbxt.blogspot.com',
+        /* Percona domains */
         'www.percona.com',
+        /* Following are doubtful ones. */
         'mysqldatabaseadministration.blogspot.com',
-        'ronaldbradford.com',
-        'xaprb.com',
     );
-    if (in_array(/*overload*/mb_strtolower($domain), $domainWhiteList)) {
+    if (in_array($domain, $domainWhiteList)) {
         return true;
     }
 
@@ -888,7 +788,7 @@ function PMA_isAllowedDomain($url)
 
 
 /**
- * Adds JS code snippets to be displayed by the PMA_Response class.
+ * Adds JS code snippets to be displayed by the PMA\libraries\Response class.
  * Adds a newline to each snippet.
  *
  * @param string $str Js code to be added (e.g. "token=1234;")
@@ -897,7 +797,7 @@ function PMA_isAllowedDomain($url)
  */
 function PMA_addJSCode($str)
 {
-    $response = PMA_Response::getInstance();
+    $response = PMA\libraries\Response::getInstance();
     $header   = $response->getHeader();
     $scripts  = $header->getScripts();
     $scripts->addCode($str);
@@ -905,7 +805,7 @@ function PMA_addJSCode($str)
 
 /**
  * Adds JS code snippet for variable assignment
- * to be displayed by the PMA_Response class.
+ * to be displayed by the PMA\libraries\Response class.
  *
  * @param string $key    Name of value to set
  * @param mixed  $value  Value to set, can be either string or array of strings
@@ -949,13 +849,13 @@ function PMA_previewSQL($query_data)
         $retval .= __('No change');
     } elseif (is_array($query_data)) {
         foreach ($query_data as $query) {
-            $retval .= PMA_Util::formatSql($query);
+            $retval .= PMA\libraries\Util::formatSql($query);
         }
     } else {
-        $retval .= PMA_Util::formatSql($query_data);
+        $retval .= PMA\libraries\Util::formatSql($query_data);
     }
     $retval .= '</div>';
-    $response = PMA_Response::getInstance();
+    $response = PMA\libraries\Response::getInstance();
     $response->addJSON('sql_data', $retval);
     exit;
 }
@@ -971,7 +871,7 @@ function PMA_emptyRecursive($value)
 {
     $empty = true;
     if (is_array($value)) {
-        PMA_arrayWalkRecursive(
+        array_walk_recursive(
             $value,
             function ($item) use (&$empty) {
                 $empty = $empty && empty($item);
@@ -1019,6 +919,82 @@ function PMA_setGlobalDbOrTable($param)
     }
 }
 
+/**
+ * PATH_INFO could be compromised if set, so remove it from PHP_SELF
+ * and provide a clean PHP_SELF here
+ *
+ * @return void
+ */
+function PMA_cleanupPathInfo()
+{
+    global $PMA_PHP_SELF;
+
+    $PMA_PHP_SELF = PMA_getenv('PHP_SELF');
+    if (empty($PMA_PHP_SELF)) {
+        $PMA_PHP_SELF = urldecode(PMA_getenv('REQUEST_URI'));
+    }
+    $_PATH_INFO = PMA_getenv('PATH_INFO');
+    if (! empty($_PATH_INFO) && ! empty($PMA_PHP_SELF)) {
+        $question_pos = mb_strpos($PMA_PHP_SELF, '?');
+        if ($question_pos != false) {
+            $PMA_PHP_SELF = mb_substr($PMA_PHP_SELF, 0, $question_pos);
+        }
+        $path_info_pos = mb_strrpos($PMA_PHP_SELF, $_PATH_INFO);
+        if ($path_info_pos !== false) {
+            $path_info_part = mb_substr($PMA_PHP_SELF, $path_info_pos, mb_strlen($_PATH_INFO));
+            if ($path_info_part == $_PATH_INFO) {
+                $PMA_PHP_SELF = mb_substr($PMA_PHP_SELF, 0, $path_info_pos);
+            }
+        }
+    }
+
+    $path = [];
+    foreach(explode('/', $PMA_PHP_SELF) as $part) {
+        // ignore parts that have no value
+        if (empty($part) || $part === '.') continue;
+
+        if ($part !== '..') {
+            // cool, we found a new part
+            array_push($path, $part);
+        } else if (count($path) > 0) {
+            // going back up? sure
+            array_pop($path);
+        }
+        // Here we intentionall ignore case where we go too up
+        // as there is nothing sane to do
+    }
+
+    $PMA_PHP_SELF = htmlspecialchars('/' . join('/', $path));
+}
+
+/**
+ * Checks that required PHP extensions are there.
+ * @return void
+ */
+function PMA_checkExtensions()
+{
+    /**
+     * Warning about mbstring.
+     */
+    if (! function_exists('mb_detect_encoding')) {
+        PMA_warnMissingExtension('mbstring', true);
+    }
+
+    /**
+     * We really need this one!
+     */
+    if (! function_exists('preg_replace')) {
+        PMA_warnMissingExtension('pcre', true);
+    }
+
+    /**
+     * JSON is required in several places.
+     */
+    if (! function_exists('json_encode')) {
+        PMA_warnMissingExtension('json', true);
+    }
+}
+
 /* Compatibility with PHP < 5.6 */
 if(! function_exists('hash_equals')) {
     function hash_equals($a, $b) {
@@ -1027,3 +1003,153 @@ if(! function_exists('hash_equals')) {
         return ! $ret;
     }
 }
+/* Compatibility with PHP < 5.1 or PHP without hash extension */
+if (! function_exists('hash_hmac')) {
+    function hash_hmac($algo, $data, $key, $raw_output = false)
+    {
+        $algo = strtolower($algo);
+        $pack = 'H'.strlen($algo('test'));
+        $size = 64;
+        $opad = str_repeat(chr(0x5C), $size);
+        $ipad = str_repeat(chr(0x36), $size);
+
+        if (strlen($key) > $size) {
+            $key = str_pad(pack($pack, $algo($key)), $size, chr(0x00));
+        } else {
+            $key = str_pad($key, $size, chr(0x00));
+        }
+
+        for ($i = 0; $i < strlen($key) - 1; $i++) {
+            $opad[$i] = $opad[$i] ^ $key[$i];
+            $ipad[$i] = $ipad[$i] ^ $key[$i];
+        }
+
+        $output = $algo($opad.pack($pack, $algo($ipad.$data)));
+
+        return ($raw_output) ? pack($pack, $output) : $output;
+    }
+}
+
+/**
+ * Sanitizes MySQL hostname
+ *
+ * * strips p: prefix(es)
+ *
+ * @param string $name User given hostname
+ *
+ * @return string
+ */
+function PMA_sanitizeMySQLHost($name)
+{
+    while (strtolower(substr($name, 0, 2)) == 'p:') {
+        $name = substr($name, 2);
+    }
+
+    return $name;
+}
+
+/**
+ * Sanitizes MySQL username
+ *
+ * * strips part behind null byte
+ *
+ * @param string $name User given username
+ *
+ * @return string
+ */
+function PMA_sanitizeMySQLUser($name)
+{
+    $position = strpos($name, chr(0));
+    if ($position !== false) {
+        return substr($name, 0, $position);
+    }
+    return $name;
+}
+
+/**
+ * Safe unserializer wrapper
+ *
+ * It does not unserialize data containing objects
+ *
+ * @param string $data Data to unserialize
+ *
+ * @return mixed
+ */
+function PMA_safeUnserialize($data)
+{
+    if (! is_string($data)) {
+        return null;
+    }
+
+    /* validate serialized data */
+    $length = strlen($data);
+    $depth = 0;
+    for ($i = 0; $i < $length; $i++) {
+        $value = $data[$i];
+
+        switch ($value)
+        {
+            case '}':
+                /* end of array */
+                if ($depth <= 0) {
+                    return null;
+                }
+                $depth--;
+                break;
+            case 's':
+                /* string */
+                // parse sting length
+                $strlen = intval(substr($data, $i + 2));
+                // string start
+                $i = strpos($data, ':', $i + 2);
+                if ($i === false) {
+                    return null;
+                }
+                // skip string, quotes and ;
+                $i += 2 + $strlen + 1;
+                if ($data[$i] != ';') {
+                    return null;
+                }
+                break;
+
+            case 'b':
+            case 'i':
+            case 'd':
+                /* bool, integer or double */
+                // skip value to sepearator
+                $i = strpos($data, ';', $i);
+                if ($i === false) {
+                    return null;
+                }
+                break;
+            case 'a':
+                /* array */
+                // find array start
+                $i = strpos($data, '{', $i);
+                if ($i === false) {
+                    return null;
+                }
+                // remember nesting
+                $depth++;
+                break;
+            case 'N':
+                /* null */
+                // skip to end
+                $i = strpos($data, ';', $i);
+                if ($i === false) {
+                    return null;
+                }
+                break;
+            default:
+                /* any other elements are not wanted */
+                return null;
+        }
+    }
+
+    // check unterminated arrays
+    if ($depth > 0) {
+        return null;
+    }
+
+    return unserialize($data);
+}
