@@ -5,10 +5,7 @@
  *
  * @package PhpMyAdmin
  */
-
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
+use PMA\libraries\Table;
 
 /**
  * Transforms the radio button field_key into 4 arrays
@@ -22,10 +19,11 @@ function PMA_getIndexedColumns()
     $field_index    = json_decode($_REQUEST['indexes'], true);
     $field_unique   = json_decode($_REQUEST['unique_indexes'], true);
     $field_fulltext = json_decode($_REQUEST['fulltext_indexes'], true);
+    $field_spatial = json_decode($_REQUEST['spatial_indexes'], true);
 
     return array(
         $field_cnt, $field_primary, $field_index, $field_unique,
-        $field_fulltext
+        $field_fulltext, $field_spatial
     );
 }
 
@@ -53,7 +51,7 @@ function PMA_buildColumnCreationStatement(
         }
 
         $definition = PMA_getStatementPrefix($is_create_tbl) .
-                PMA_Table::generateFieldSpec(
+                Table::generateFieldSpec(
                     trim($_REQUEST['field_name'][$i]),
                     $_REQUEST['field_type'][$i],
                     $_REQUEST['field_length'][$i],
@@ -71,6 +69,12 @@ function PMA_buildColumnCreationStatement(
                     : false,
                     isset($_REQUEST['field_comments'][$i])
                     ? $_REQUEST['field_comments'][$i]
+                    : '',
+                    isset($_REQUEST['field_virtuality'][$i])
+                    ? $_REQUEST['field_virtuality'][$i]
+                    : '',
+                    isset($_REQUEST['field_expression'][$i])
+                    ? $_REQUEST['field_expression'][$i]
                     : ''
                 );
 
@@ -94,26 +98,26 @@ function PMA_setColumnCreationStatementSuffix($current_field_num,
     $is_create_tbl = true
 ) {
     // no suffix is needed if request is a table creation
-    $sql_suffix = " ";
+    $sql_suffix = ' ';
     if ($is_create_tbl) {
         return $sql_suffix;
     }
 
-    if ($_REQUEST['field_where'] == 'last') {
+    if ((string) $_REQUEST['field_where'] === 'last') {
         return $sql_suffix;
     }
 
     // Only the first field can be added somewhere other than at the end
-    if ($current_field_num == 0) {
-        if ($_REQUEST['field_where'] == 'first') {
+    if ((int) $current_field_num === 0) {
+        if ((string) $_REQUEST['field_where'] === 'first') {
             $sql_suffix .= ' FIRST';
         } else {
             $sql_suffix .= ' AFTER '
-                    . PMA_Util::backquote($_REQUEST['after_field']);
+                    . PMA\libraries\Util::backquote($_REQUEST['after_field']);
         }
     } else {
         $sql_suffix .= ' AFTER '
-                . PMA_Util::backquote(
+                . PMA\libraries\Util::backquote(
                     $_REQUEST['field_name'][$current_field_num - 1]
                 );
     }
@@ -144,12 +148,12 @@ function PMA_buildIndexStatements($index, $index_choice,
         . ' ' . $index_choice;
 
     if (! empty($index['Key_name']) && $index['Key_name'] != 'PRIMARY') {
-        $sql_query .= ' ' . PMA_Util::backquote($index['Key_name']);
+        $sql_query .= ' ' . PMA\libraries\Util::backquote($index['Key_name']);
     }
 
     $index_fields = array();
     foreach ($index['columns'] as $key => $column) {
-        $index_fields[$key] = PMA_Util::backquote(
+        $index_fields[$key] = PMA\libraries\Util::backquote(
             $_REQUEST['field_name'][$column['col_index']]
         );
         if ($column['size']) {
@@ -162,26 +166,27 @@ function PMA_buildIndexStatements($index, $index_choice,
     $keyBlockSizes = $index['Key_block_size'];
     if (! empty($keyBlockSizes)) {
         $sql_query .= " KEY_BLOCK_SIZE = "
-             . PMA_Util::sqlAddSlashes($keyBlockSizes);
+             . $GLOBALS['dbi']->escapeString($keyBlockSizes);
     }
 
     // specifying index type is allowed only for primary, unique and index only
     $type = $index['Index_type'];
     if ($index['Index_choice'] != 'SPATIAL'
         && $index['Index_choice'] != 'FULLTEXT'
-        && in_array($type, PMA_Index::getIndexTypes())
+        && in_array($type, PMA\libraries\Index::getIndexTypes())
     ) {
         $sql_query .= ' USING ' . $type;
     }
 
     $parser = $index['Parser'];
     if ($index['Index_choice'] == 'FULLTEXT' && ! empty($parser)) {
-        $sql_query .= " WITH PARSER " . PMA_Util::sqlAddSlashes($parser);
+        $sql_query .= " WITH PARSER " . $GLOBALS['dbi']->escapeString($parser);
     }
 
     $comment = $index['Index_comment'];
     if (! empty($comment)) {
-        $sql_query .= " COMMENT '" . PMA_Util::sqlAddSlashes($comment) . "'";
+        $sql_query .= " COMMENT '" . $GLOBALS['dbi']->escapeString($comment)
+            . "'";
     }
 
     $statement[] = $sql_query;
@@ -242,7 +247,7 @@ function PMA_getColumnCreationStatements($is_create_tbl = true)
 {
     $sql_statement = "";
     list($field_cnt, $field_primary, $field_index,
-            $field_unique, $field_fulltext
+            $field_unique, $field_fulltext, $field_spatial
             ) = PMA_getIndexedColumns();
     $definitions = PMA_buildColumnCreationStatement(
         $field_cnt, $is_create_tbl
@@ -271,6 +276,11 @@ function PMA_getColumnCreationStatements($is_create_tbl = true)
         $definitions, $is_create_tbl, $field_fulltext, "FULLTEXT"
     );
 
+    // Builds the SPATIAL statements
+    $definitions = PMA_mergeIndexStatements(
+        $definitions, $is_create_tbl, $field_spatial, "SPATIAL"
+    );
+
     if (count($definitions)) {
         $sql_statement = implode(', ', $definitions);
     }
@@ -280,6 +290,109 @@ function PMA_getColumnCreationStatements($is_create_tbl = true)
 
 }
 
+/**
+ * Returns the partitioning clause
+ *
+ * @return string partitioning clause
+ */
+function PMA_getPartitionsDefinition()
+{
+    $sql_query = "";
+    if (! empty($_REQUEST['partition_by'])
+        && ! empty($_REQUEST['partition_expr'])
+        && ! empty($_REQUEST['partition_count'])
+        && $_REQUEST['partition_count'] > 1
+    ) {
+        $sql_query .= " PARTITION BY " . $_REQUEST['partition_by']
+            . " (" . $_REQUEST['partition_expr'] . ")"
+            . " PARTITIONS " . $_REQUEST['partition_count'];
+    }
+
+    if (! empty($_REQUEST['subpartition_by'])
+        && ! empty($_REQUEST['subpartition_expr'])
+        && ! empty($_REQUEST['subpartition_count'])
+        && $_REQUEST['subpartition_count'] > 1
+    ) {
+        $sql_query .= " SUBPARTITION BY " . $_REQUEST['subpartition_by']
+           . " (" . $_REQUEST['subpartition_expr'] . ")"
+           . " SUBPARTITIONS " . $_REQUEST['subpartition_count'];
+    }
+
+    if (! empty($_REQUEST['partitions'])) {
+        $i = 0;
+        $partitions = array();
+        foreach ($_REQUEST['partitions'] as $partition) {
+            $partitions[] = PMA_getPartitionDefinition($partition);
+            $i++;
+        }
+        $sql_query .= " (" . implode(", ", $partitions) . ")";
+    }
+
+    return $sql_query;
+}
+
+/**
+ * Returns the definition of a partition/subpartition
+ *
+ * @param array   $partition      array of partition/subpartition detiails
+ * @param boolean $isSubPartition whether a subpartition
+ *
+ * @return string partition/subpartition definition
+ */
+function PMA_getPartitionDefinition($partition, $isSubPartition = false)
+{
+    $sql_query = " " . ($isSubPartition ? "SUB" : "") . "PARTITION ";
+    $sql_query .= $partition['name'];
+
+    if (! empty($partition['value_type'])) {
+        $sql_query .= " VALUES " . $partition['value_type'];
+
+        if ($partition['value_type'] != 'LESS THAN MAXVALUE') {
+            $sql_query .= " (" . $partition['value'] . ")";
+        }
+    }
+
+    if (! empty($partition['engine'])) {
+        $sql_query .= " ENGINE = " . $partition['engine'];
+    }
+    if (! empty($partition['comment'])) {
+        $sql_query .= " COMMENT = '" . $partition['comment'] . "'";
+    }
+    if (! empty($partition['data_directory'])) {
+        $sql_query .= " DATA DIRECTORY = '" . $partition['data_directory'] . "'";
+    }
+    if (! empty($partition['index_directory'])) {
+        $sql_query .= " INDEX_DIRECTORY = '" . $partition['index_directory'] . "'";
+    }
+    if (! empty($partition['max_rows'])) {
+        $sql_query .= " MAX_ROWS = " . $partition['max_rows'];
+    }
+    if (! empty($partition['min_rows'])) {
+        $sql_query .= " MIN_ROWS = " . $partition['min_rows'];
+    }
+    if (! empty($partition['tablespace'])) {
+        $sql_query .= " TABLESPACE = " . $partition['tablespace'];
+    }
+    if (! empty($partition['node_group'])) {
+        $sql_query .= " NODEGROUP = " . $partition['node_group'];
+    }
+
+    if (! empty($partition['subpartitions'])) {
+        $j = 0;
+        $subpartitions = array();
+        foreach ($partition['subpartitions'] as $subpartition) {
+            $subpartitions[] = PMA_getPartitionDefinition(
+                $subpartition,
+                true
+            );
+            $j++;
+        }
+        $sql_query .= " (" . implode(", ", $subpartitions) . ")";
+    }
+
+    return $sql_query;
+}
+
 /**
  * Function to get table creation sql query
  *
@@ -294,8 +407,8 @@ function PMA_getTableCreationQuery($db, $table)
     $sql_statement = PMA_getColumnCreationStatements(true);
 
     // Builds the 'create table' statement
-    $sql_query = 'CREATE TABLE ' . PMA_Util::backquote($db) . '.'
-        . PMA_Util::backquote(trim($table)) . ' (' . $sql_statement . ')';
+    $sql_query = 'CREATE TABLE ' . PMA\libraries\Util::backquote($db) . '.'
+        . PMA\libraries\Util::backquote(trim($table)) . ' (' . $sql_statement . ')';
 
     // Adds table type, character set, comments and partition definition
     if (!empty($_REQUEST['tbl_storage_engine'])
@@ -311,17 +424,13 @@ function PMA_getTableCreationQuery($db, $table)
         && $_REQUEST['tbl_storage_engine'] == 'FEDERATED'
     ) {
         $sql_query .= " CONNECTION = '"
-            . PMA_Util::sqlAddSlashes($_REQUEST['connection']) . "'";
+            . $GLOBALS['dbi']->escapeString($_REQUEST['connection']) . "'";
     }
     if (!empty($_REQUEST['comment'])) {
         $sql_query .= ' COMMENT = \''
-            . PMA_Util::sqlAddSlashes($_REQUEST['comment']) . '\'';
-    }
-    if (!empty($_REQUEST['partition_definition'])) {
-        $sql_query .= ' ' . PMA_Util::sqlAddSlashes(
-            $_REQUEST['partition_definition']
-        );
+            . $GLOBALS['dbi']->escapeString($_REQUEST['comment']) . '\'';
     }
+    $sql_query .= PMA_getPartitionsDefinition();
     $sql_query .= ';';
 
     return $sql_query;
@@ -334,13 +443,18 @@ function PMA_getTableCreationQuery($db, $table)
  */
 function PMA_getNumberOfFieldsFromRequest()
 {
-    if (isset($_REQUEST['submit_num_fields'])) {
-        $num_fields = $_REQUEST['orig_num_fields'] + $_REQUEST['added_fields'];
+    if (isset($_REQUEST['submit_num_fields'])) { // adding new fields
+        $num_fields = min(
+            4096,
+            intval($_REQUEST['orig_num_fields']) + intval($_REQUEST['added_fields'])
+        );
+    } elseif (isset($_REQUEST['orig_num_fields'])) { // retaining existing fields
+        $num_fields = min(4096, intval($_REQUEST['orig_num_fields']));
     } elseif (isset($_REQUEST['num_fields'])
         && intval($_REQUEST['num_fields']) > 0
-    ) {
-        $num_fields = (int) $_REQUEST['num_fields'];
-    } else {
+    ) { // new table with specified number of fields
+        $num_fields = min(4096, intval($_REQUEST['num_fields']));
+    } else { // new table with unspecified number of fields
         $num_fields = 4;
     }
 
@@ -363,18 +477,18 @@ function PMA_tryColumnCreationQuery($db, $table, $err_url)
 
     // To allow replication, we first select the db to use and then run queries
     // on this db.
-    $GLOBALS['dbi']->selectDb($db)
-        or PMA_Util::mysqlDie(
+    if (!($GLOBALS['dbi']->selectDb($db))) {
+        PMA\libraries\Util::mysqlDie(
             $GLOBALS['dbi']->getError(),
-            'USE ' . PMA_Util::backquote($db), false,
+            'USE ' . PMA\libraries\Util::backquote($db), false,
             $err_url
         );
+    }
     $sql_query    = 'ALTER TABLE ' .
-        PMA_Util::backquote($table) . ' ' . $sql_statement . ';';
+        PMA\libraries\Util::backquote($table) . ' ' . $sql_statement . ';';
     // If there is a request for SQL previewing.
     if (isset($_REQUEST['preview_sql'])) {
         PMA_previewSQL($sql_query);
     }
     return array($GLOBALS['dbi']->tryQuery($sql_query) , $sql_query);
 }
-?>
