@@ -6,12 +6,6 @@
  * @package PhpMyAdmin
  */
 
-/*
- * Include for handleContext() and configureCurl in PMA_sendErrorReport()
- */
-require_once 'libraries/Util.class.php';
-
-
 if (! defined('PHPMYADMIN')) {
     exit;
 }
@@ -40,12 +34,7 @@ function PMA_getPrettyReportData()
 {
     $report = PMA_getReportData();
 
-    /* JSON_PRETTY_PRINT available since PHP 5.4 */
-    if (defined('JSON_PRETTY_PRINT')) {
-        return json_encode($report, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES);
-    }
-
-    return PMA_prettyPrint($report);
+    return json_encode($report, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES);
 }
 
 /**
@@ -54,7 +43,7 @@ function PMA_getPrettyReportData()
  *
  * @param string $exception_type whether exception is 'js' or 'php'
  *
- * @return Array error report if success, Empty Array otherwise
+ * @return array error report if success, Empty Array otherwise
  */
 function PMA_getReportData($exception_type = 'js')
 {
@@ -102,7 +91,7 @@ function PMA_getReportData($exception_type = 'js')
             return array();
         }
         foreach ($_SESSION['prev_errors'] as $errorObj) {
-            /* @var $errorObj PMA_Error */
+            /* @var $errorObj PMA\libraries\Error */
             if ($errorObj->getLine()
                 && $errorObj->getType()
                 && $errorObj->getNumber() != E_USER_WARNING
@@ -142,7 +131,7 @@ function PMA_getReportData($exception_type = 'js')
  *
  * @param String $url the url to sanitize
  *
- * @return Array the uri and script name
+ * @return array the uri and script name
  */
 function PMA_sanitizeUrl($url)
 {
@@ -151,7 +140,7 @@ function PMA_sanitizeUrl($url)
         && preg_match("<PMAURL-\d+:>", $components["fragment"], $matches)
     ) {
         $uri = str_replace($matches[0], "", $components["fragment"]);
-        $url = "http://dummy_host/" . $uri;
+        $url = "https://example.com/" . $uri;
         $components = parse_url($url);
     }
 
@@ -182,22 +171,39 @@ function PMA_sanitizeUrl($url)
 /**
  * Sends report data to the error reporting server
  *
- * @param Array $report the report info to be sent
+ * @param array $report the report info to be sent
  *
  * @return String the reply of the server
  */
 function PMA_sendErrorReport($report)
 {
     $data_string = json_encode($report);
-    if (ini_get('allow_url_fopen')) {
+    if (function_exists('curl_init')) {
+        $curl_handle = curl_init(SUBMISSION_URL);
+        if ($curl_handle === false) {
+            return null;
+        }
+        $curl_handle = PMA\libraries\Util::configureCurl($curl_handle);
+        curl_setopt($curl_handle, CURLOPT_CUSTOMREQUEST, "POST");
+        curl_setopt(
+            $curl_handle, CURLOPT_HTTPHEADER,
+            array('Expect:', 'Content-Type: application/json')
+        );
+        curl_setopt($curl_handle, CURLOPT_POSTFIELDS, $data_string);
+        curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, 1);
+        $response = curl_exec($curl_handle);
+        curl_close($curl_handle);
+
+        return $response;
+    } else if (ini_get('allow_url_fopen')) {
         $context = array("http" =>
             array(
                 'method'  => 'POST',
                 'content' => $data_string,
-                'header' => "Content-Type: multipart/form-data\r\n",
+                'header' => "Content-Type: application/json\r\n",
             )
         );
-        $context = PMA_Util::handleContext($context);
+        $context = PMA\libraries\Util::handleContext($context);
         $response = @file_get_contents(
             SUBMISSION_URL,
             false,
@@ -206,23 +212,7 @@ function PMA_sendErrorReport($report)
         return $response;
     }
 
-    if (!function_exists('curl_init')) {
-        return null;
-    }
-
-    $curl_handle = curl_init(SUBMISSION_URL);
-    if ($curl_handle === false) {
-        return null;
-    }
-    $curl_handle = PMA_Util::configureCurl($curl_handle);
-    curl_setopt($curl_handle, CURLOPT_CUSTOMREQUEST, "POST");
-    curl_setopt($curl_handle, CURLOPT_HTTPHEADER, array('Expect:'));
-    curl_setopt($curl_handle, CURLOPT_POSTFIELDS, $data_string);
-    curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, 1);
-    $response = curl_exec($curl_handle);
-    curl_close($curl_handle);
-
-    return $response;
+    return null;
 }
 
 /**
@@ -246,7 +236,7 @@ function PMA_countLines($filename)
     foreach (explode('/', $filename) as $part) {
         if ($part == '..') {
             $depath--;
-        } elseif ($part != '.') {
+        } elseif ($part != '.' || $part === '') {
             $depath++;
         }
         if ($depath < 0) {
@@ -273,11 +263,11 @@ function PMA_countLines($filename)
  *
  * uses the $LINE_COUNT global array of file names and line numbers
  *
- * @param Array   $filenames         list of files in order of concatenation
+ * @param array   $filenames         list of files in order of concatenation
  * @param Integer $cumulative_number the cumulative line number in the
  *                                   concatenated files
  *
- * @return Array the filename and line number
+ * @return array the filename and line number
  * Returns two variables in an array:
  * - A String $filename the filename where the requested cumulative number
  *   exists
@@ -304,16 +294,16 @@ function PMA_getLineNumber($filenames, $cumulative_number)
  * translates the cumulative line numbers in the stack trace as well as sanitize
  * urls and trim long lines in the context
  *
- * @param Array $stack the stack trace
+ * @param array $stack the stack trace
  *
- * @return Array $stack the modified stack trace
+ * @return array $stack the modified stack trace
  */
 function PMA_translateStacktrace($stack)
 {
     foreach ($stack as &$level) {
         foreach ($level["context"] as &$line) {
-            if (/*overload*/mb_strlen($line) > 80) {
-                $line = /*overload*/mb_substr($line, 0, 75) . "//...";
+            if (mb_strlen($line) > 80) {
+                $line = mb_substr($line, 0, 75) . "//...";
             }
         }
         if (preg_match("<js/get_scripts.js.php\?(.*)>", $level["url"], $matches)) {
@@ -354,50 +344,6 @@ function PMA_getErrorReportForm()
         $datas['hidden_fields'] = PMA_getHiddenFields($reportData);
     }
 
-    include_once './libraries/Template.class.php';
-    return PMA\Template::get('error/report_form')
+    return PMA\libraries\Template::get('error/report_form')
         ->render($datas);
 }
-
-/**
- * generates the error report form to collect user description and preview the
- * report before being sent
- *
- * @return String the form
- */
-function PMA_hasLatestLineCounts()
-{
-    $line_counts_time = filemtime("js/line_counts.php");
-    $js_time = filemtime("js");
-    return $line_counts_time >= $js_time;
-}
-
-/**
- * pretty print a variable for the user
- *
- * @param mixed  $object    the variable to pretty print
- * @param String $namespace the namespace to use for printing values
- *
- * @return String the human readable form of the variable
- */
-function PMA_prettyPrint($object, $namespace="")
-{
-    if (! is_array($object)) {
-        if (empty($namespace)) {
-            return "$object\n";
-        } else {
-            return "$namespace: \"$object\"\n";
-        }
-    }
-    $output = "";
-    foreach ($object as $key => $value) {
-        if ($namespace == "") {
-            $new_namespace =  "$key";
-        } else {
-            $new_namespace =  $namespace . "[$key]";
-        }
-        $output .= PMA_prettyPrint($value, $new_namespace);
-    }
-    return $output;
-}
-
