@@ -5,32 +5,65 @@
  *
  * @package PhpMyAdmin
  */
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
 
 /**
  * Checks whether given link is valid
  *
- * @param string $url URL to check
+ * @param string  $url   URL to check
+ * @param boolean $http  Whether to allow http links
+ * @param boolean $other Whether to allow ftp and mailto links
  *
  * @return boolean True if string can be used as link
  */
-function PMA_checkLink($url)
+function PMA_checkLink($url, $http=false, $other=false)
 {
+    $url = strtolower($url);
     $valid_starts = array(
-        'http://',
         'https://',
-        './url.php?url=http%3A%2F%2F',
-        './url.php?url=https%3A%2F%2F',
+        './url.php?url=https%3a%2f%2f',
         './doc/html/',
+        # possible return values from Util::getScriptNameForOption
+        './index.php?',
+        './server_databases.php?',
+        './server_status.php?',
+        './server_variables.php?',
+        './server_privileges.php?',
+        './db_structure.php?',
+        './db_sql.php?',
+        './db_search.php?',
+        './db_operations.php?',
+        './tbl_structure.php?',
+        './tbl_sql.php?',
+        './tbl_select.php?',
+        './tbl_change.php?',
+        './sql.php?',
+        # Hardcoded options in libraries/special_schema_links.lib.php
+        './db_events.php?',
+        './db_routines.php?',
+        './server_privileges.php?',
+        './tbl_structure.php?',
     );
+    // Adjust path to setup script location
+    if (defined('PMA_SETUP')) {
+        foreach ($valid_starts as $key => $value) {
+            if (substr($value, 0, 2) === './') {
+                $valid_starts[$key] = '.' . $value;
+            }
+        }
+    }
+    if ($other) {
+        $valid_starts[] = 'mailto:';
+        $valid_starts[] = 'ftp://';
+    }
+    if ($http) {
+        $valid_starts[] = 'http://';
+    }
     if (defined('PMA_SETUP')) {
         $valid_starts[] = '?page=form&';
         $valid_starts[] = '?page=servers&';
     }
     foreach ($valid_starts as $val) {
-        if (/*overload*/mb_substr($url, 0, /*overload*/mb_strlen($val)) == $val) {
+        if (substr($url, 0, strlen($val)) == $val) {
             return true;
         }
     }
@@ -59,6 +92,9 @@ function PMA_replaceBBLink($found)
     $target = '';
     if (! empty($found[3])) {
         $target = ' target="' . $found[3] . '"';
+        if ($found[3] == '_blank') {
+            $target .= ' rel="noopener noreferrer"';
+        }
     }
 
     /* Construct url */
@@ -80,16 +116,21 @@ function PMA_replaceBBLink($found)
  */
 function PMA_replaceDocLink($found)
 {
-    $anchor = $found[1];
-    if (strncmp('faq', $anchor, 3) == 0) {
-        $page = 'faq';
-    } else if (strncmp('cfg', $anchor, 3) == 0) {
-        $page = 'cfg';
+    if (count($found) >= 4) {
+        $page = $found[1];
+        $anchor = $found[3];
     } else {
-        /* Guess */
-        $page = 'setup';
+        $anchor = $found[1];
+        if (strncmp('faq', $anchor, 3) == 0) {
+            $page = 'faq';
+        } else if (strncmp('cfg', $anchor, 3) == 0) {
+            $page = 'config';
+        } else {
+            /* Guess */
+            $page = 'setup';
+        }
     }
-    $link = PMA_Util::getDocuLink($page, $anchor);
+    $link = PMA\libraries\Util::getDocuLink($page, $anchor);
     return '<a href="' . $link . '" target="documentation">';
 }
 
@@ -133,7 +174,9 @@ function PMA_sanitize($message, $escape = false, $safe = false)
         '[sup]'     => '<sup>',
         '[/sup]'    => '</sup>',
          // used in common.inc.php:
-        '[conferr]' => '<iframe src="show_config_errors.php" />',
+        '[conferr]' => '<iframe src="show_config_errors.php"><a href="show_config_errors.php">show_config_errors.php</a></iframe>',
+         // used in libraries/Util.php
+        '[dochelpicon]' => PMA\libraries\Util::getImage('b_help.png', __('Documentation')),
     );
 
     $message = strtr($message, $replace_pairs);
@@ -146,7 +189,7 @@ function PMA_sanitize($message, $escape = false, $safe = false)
 
     /* Replace documentation links */
     $message = preg_replace_callback(
-        '/\[doc@([a-zA-Z0-9_-]+)\]/',
+        '/\[doc@([a-zA-Z0-9_-]+)(@([a-zA-Z0-9_-]*))?\]/',
         'PMA_replaceDocLink',
         $message
     );
