@@ -1,6 +1,5 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
-
 /**
  * functions for displaying server status variables
  *
@@ -8,14 +7,12 @@
  *
  * @package PhpMyAdmin
  */
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
+use PMA\libraries\ServerStatusData;
 
 /**
  * Returns the html for the list filter
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
+ * @param ServerStatusData $ServerStatusData Server status data
  *
  * @return string
  */
@@ -37,7 +34,7 @@ function PMA_getHtmlForFilter($ServerStatusData)
     $retval  = '';
     $retval .= '<fieldset id="tableFilter">';
     $retval .= '<legend>' . __('Filters') . '</legend>';
-    $retval .= '<form action="server_status_variables.php?'
+    $retval .= '<form action="server_status_variables.php'
         . PMA_URL_getCommon() . '">';
     $retval .= '<input type="submit" value="' . __('Refresh') . '" />';
     $retval .= '<div class="formelement">';
@@ -57,7 +54,7 @@ function PMA_getHtmlForFilter($ServerStatusData)
     $retval .= '<option value="">' . __('Filter by category…') . '</option>';
 
     foreach ($ServerStatusData->sections as $section_id => $section_name) {
-        if (isset($ServerStatusData->categoryUsed[$section_id])) {
+        if (isset($ServerStatusData->sectionUsed[$section_id])) {
             if (! empty($_REQUEST['filterCategory'])
                 && $_REQUEST['filterCategory'] == $section_id
             ) {
@@ -87,7 +84,7 @@ function PMA_getHtmlForFilter($ServerStatusData)
 /**
  * Prints the suggestion links
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
+ * @param ServerStatusData $ServerStatusData Server status data
  *
  * @return string
  */
@@ -98,13 +95,13 @@ function PMA_getHtmlForLinkSuggestions($ServerStatusData)
     $retval .= '<p class="notice">' . __('Related links:');
     foreach ($ServerStatusData->links as $section_name => $section_links) {
         $retval .= '<span class="status_' . $section_name . '"> ';
-        $i=0;
+        $i = 0;
         foreach ($section_links as $link_name => $link_url) {
             if ($i > 0) {
                 $retval .= ', ';
             }
             if ('doc' == $link_name) {
-                $retval .= PMA_Util::showMySQLDocu($link_url);
+                $retval .= PMA\libraries\Util::showMySQLDocu($link_url);
             } else {
                 $retval .= '<a href="' . $link_url . '">' . $link_name . '</a>';
             }
@@ -122,7 +119,7 @@ function PMA_getHtmlForLinkSuggestions($ServerStatusData)
 /**
  * Returns a table with variables information
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
+ * @param ServerStatusData $ServerStatusData Server status data
  *
  * @return string
  */
@@ -171,11 +168,11 @@ function PMA_getHtmlForVariablesList($ServerStatusData)
         'Slow_launch_threads' => 0,
 
         // depends on Key_read_requests
-        // normaly lower then 1:0.01
+        // normally lower then 1:0.01
         'Key_reads' => isset($ServerStatusData->status['Key_read_requests'])
             ? (0.01 * $ServerStatusData->status['Key_read_requests']) : 0,
         // depends on Key_write_requests
-        // normaly nearly 1:1
+        // normally nearly 1:1
         'Key_writes' => isset($ServerStatusData->status['Key_write_requests'])
             ? (0.9 * $ServerStatusData->status['Key_write_requests']) : 0,
 
@@ -202,15 +199,15 @@ function PMA_getHtmlForVariablesList($ServerStatusData)
 /**
  * Returns HTML for render variables list
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
- * @param Array                $alerts           Alert Array
- * @param Array                $strShowStatus    Status Array
+ * @param ServerStatusData $ServerStatusData Server status data
+ * @param array            $alerts           Alert Array
+ * @param array            $strShowStatus    Status Array
  *
  * @return string
  */
 function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatus)
 {
-    $retval  = '<table class="data sortable noclick" id="serverstatusvariables">';
+    $retval  = '<table class="data noclick" id="serverstatusvariables">';
     $retval .= '<col class="namecol" />';
     $retval .= '<col class="valuecol" />';
     $retval .= '<col class="descrcol" />';
@@ -236,8 +233,8 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
         $retval .= htmlspecialchars(str_replace('_', ' ', $name));
         // Fields containing % are calculated,
         // they can not be described in MySQL documentation
-        if (strpos($name, '%') === false) {
-            $retval .= PMA_Util::showMySQLDocu(
+        if (mb_strpos($name, '%') === false) {
+            $retval .= PMA\libraries\Util::showMySQLDocu(
                 'server-status-variables',
                 false,
                 'statvar_' . $name
@@ -253,21 +250,25 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
                 $retval .= '<span class="allfine">';
             }
         }
-        if ('%' === substr($name, -1, 1)) {
-            $retval .= htmlspecialchars(PMA_Util::formatNumber($value, 0, 2)) . ' %';
+        if (substr($name, -1) === '%') {
+            $retval .= htmlspecialchars(
+                PMA\libraries\Util::formatNumber($value, 0, 2)
+            ) . ' %';
         } elseif (strpos($name, 'Uptime') !== false) {
             $retval .= htmlspecialchars(
-                PMA_Util::timespanFormat($value)
+                PMA\libraries\Util::timespanFormat($value)
             );
         } elseif (is_numeric($value) && $value > 1000) {
             $retval .= '<abbr title="'
                 // makes available the raw value as a title
-                . htmlspecialchars(PMA_Util::formatNumber($value, 0))
+                . htmlspecialchars(PMA\libraries\Util::formatNumber($value, 0))
                 . '">'
-                . htmlspecialchars(PMA_Util::formatNumber($value, 3, 1))
+                . htmlspecialchars(PMA\libraries\Util::formatNumber($value, 3, 1))
                 . '</abbr>';
         } elseif (is_numeric($value)) {
-            $retval .= htmlspecialchars(PMA_Util::formatNumber($value, 3, 1));
+            $retval .= htmlspecialchars(
+                PMA\libraries\Util::formatNumber($value, 3, 1)
+            );
         } else {
             $retval .= htmlspecialchars($value);
         }
@@ -283,7 +284,7 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
                 $retval .= '<span class="allfine">';
             }
         }
-        $retval .= $value;
+        $retval .= htmlspecialchars($value);
         if (isset($alerts[$name])) {
             $retval .= '</span>';
         }
@@ -298,7 +299,7 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
         if (isset($ServerStatusData->links[$name])) {
             foreach ($ServerStatusData->links[$name] as $link_name => $link_url) {
                 if ('doc' == $link_name) {
-                    $retval .= PMA_Util::showMySQLDocu($link_url);
+                    $retval .= PMA\libraries\Util::showMySQLDocu($link_url);
                 } else {
                     $retval .= ' <a href="' . $link_url . '">' . $link_name . '</a>';
                 }
@@ -762,4 +763,3 @@ function PMA_getStatusVariablesDescriptions()
     );
 }
 
-?>
