@@ -14,6 +14,9 @@
  */
 require 'libraries/common.inc.php';
 
+$response = PMA\libraries\Response::getInstance();
+$response->disable();
+
 /**
  *
  */
@@ -22,7 +25,7 @@ header('Content-type: text/plain; charset=utf-8');
 $filename = LICENSE_FILE;
 
 // Check if the file is available, some distributions remove these.
-if (is_readable($filename)) {
+if (@is_readable($filename)) {
     readfile($filename);
 } else {
     printf(
