@@ -5,6 +5,9 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\Linter;
+
+$_GET['ajax_request'] = 'true';
 
 /**
  * Loading common files. Used to check for authorization, localization and to
@@ -12,11 +15,6 @@
  */
 require_once 'libraries/common.inc.php';
 
-/**
- * Loads the linter.
- */
-require_once 'libraries/Linter.class.php';
-
 /**
  * The SQL query to be analyzed.
  *
@@ -31,8 +29,20 @@ require_once 'libraries/Linter.class.php';
 $sql_query = !empty($_POST['sql_query']) ? $_POST['sql_query'] : '';
 
 // Disabling standard response.
-PMA_Response::getInstance()->disable();
+PMA\libraries\Response::getInstance()->disable();
 
 PMA_headerJSON();
 
-echo json_encode(PMA_Linter::lint($sql_query));
+if (! empty($_POST['options'])) {
+    $options = $_POST['options'];
+
+    if (! empty($options['routine_editor'])) {
+        $sql_query = 'CREATE PROCEDURE `a`() ' . $sql_query;
+    } elseif (! empty($options['trigger_editor'])) {
+        $sql_query = 'CREATE TRIGGER `a` AFTER INSERT ON `b` FOR EACH ROW ' . $sql_query;
+    } elseif (! empty($options['event_editor'])) {
+        $sql_query = 'CREATE EVENT `a` ON SCHEDULE EVERY MINUTE DO ' . $sql_query;
+    }
+}
+
+echo json_encode(Linter::lint($sql_query));
