@@ -18,7 +18,7 @@ require_once 'libraries/replication_gui.lib.php';
 /**
  * Does the common work
  */
-$response = PMA_Response::getInstance();
+$response = PMA\libraries\Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('server_privileges.js');
@@ -29,15 +29,17 @@ $scripts->addFile('replication.js');
  */
 if (! $is_superuser) {
     $html  = PMA_getHtmlForSubPageHeader('replication');
-    $html .= PMA_Message::error(__('No Privileges'))->getDisplay();
+    $html .= PMA\libraries\Message::error(__('No Privileges'))->getDisplay();
     $response->addHTML($html);
     exit;
 }
 
-//change $GLOBALS['url_params'] with $_REQUEST['url_params']
-if (isset($_REQUEST['url_params'])) {
+// change $GLOBALS['url_params'] with $_REQUEST['url_params']
+// only if it is an array
+if (isset($_REQUEST['url_params']) && is_array($_REQUEST['url_params'])) {
     $GLOBALS['url_params'] = $_REQUEST['url_params'];
 }
+
 /**
  * Handling control requests
  */
