@@ -10,13 +10,13 @@ if (!defined('PHPMYADMIN')) {
     exit;
 }
 
-$formset_id = filter_input(INPUT_GET, 'formset');
+$formset_id = isset($_GET['formset']) ? $_GET['formset'] : null;
 
 $separator = PMA_URL_getArgSeparator('html');
 echo '<ul>';
-echo '<li><a href="index.php"'
-    . ($formset_id === null ? ' class="active' : '')
-    . '">' . __('Overview') . '</a></li>';
+echo '<li><a href="index.php' , PMA_URL_getCommon() , '"'
+    , ($formset_id === null ? ' class="active' : '')
+    , '">' , __('Overview') , '</a></li>';
 
 $formsets = array(
     'Features'    => __('Features'),
@@ -28,9 +28,10 @@ $formsets = array(
 );
 
 foreach ($formsets as $formset => $label) {
-    echo '<li><a href="?page=form' . $separator . 'formset=' . $formset . '" '
-        . ($formset_id === $formset ? ' class="active' : '')
-        . '">' . $label . '</a></li>';
+    echo '<li><a href="' , PMA_URL_getCommon() , $separator , 'page=form'
+        , $separator , 'formset=' , $formset , '" '
+        , ($formset_id === $formset ? ' class="active' : '')
+        , '">' , $label , '</a></li>';
 }
 
 echo '</ul>';
