@@ -5,6 +5,7 @@
  *
  * @package PhpMyAdmin-Setup
  */
+use PMA\libraries\config\ConfigFile;
 
 /**
  * Do not include full common.
@@ -19,10 +20,8 @@ if (!file_exists('./libraries/common.inc.php')) {
 }
 
 require_once './libraries/common.inc.php';
-require_once './libraries/Util.class.php';
 require_once './libraries/config/config_functions.lib.php';
 require_once './libraries/config/messages.inc.php';
-require_once './libraries/config/ConfigFile.class.php';
 require_once './libraries/url_generating.lib.php';
 require_once './libraries/user_preferences.lib.php';
 
