@@ -11,6 +11,8 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\plugins\IOTransformationsPlugin;
+use PMA\libraries\Table;
 
 /**
  * Gets some core libraries
@@ -24,7 +26,7 @@ require_once 'libraries/insert_edit.lib.php';
 require_once 'libraries/transformations.lib.php';
 
 // Check parameters
-PMA_Util::checkParameters(array('db', 'table', 'goto'));
+PMA\libraries\Util::checkParameters(array('db', 'table', 'goto'));
 
 $GLOBALS['dbi']->selectDb($GLOBALS['db']);
 
@@ -33,7 +35,7 @@ $GLOBALS['dbi']->selectDb($GLOBALS['db']);
  */
 $goto_include = false;
 
-$response = PMA_Response::getInstance();
+$response = PMA\libraries\Response::getInstance();
 $header = $response->getHeader();
 $scripts = $header->getScripts();
 $scripts->addFile('makegrid.js');
@@ -123,9 +125,6 @@ $gis_from_wkb_functions = array(
     'MPolyFromWKB',
 );
 
-// to create an object of PMA_File class
-require_once './libraries/File.class.php';
-
 //if some posted fields need to be transformed.
 $mime_map = PMA_getMIME($GLOBALS['db'], $GLOBALS['table']);
 if ($mime_map === false) {
@@ -182,6 +181,10 @@ foreach ($loop_array as $rownumber => $where_clause) {
         = isset($_REQUEST['auto_increment']['multi_edit'][$rownumber])
         ? $_REQUEST['auto_increment']['multi_edit'][$rownumber]
         : null;
+    $multi_edit_virtual
+        = isset($_REQUEST['virtual']['multi_edit'][$rownumber])
+        ? $_REQUEST['virtual']['multi_edit'][$rownumber]
+        : null;
 
     // When a select field is nullified, it's not present in $_REQUEST
     // so initialize it; this way, the foreach($multi_edit_columns) will process it
@@ -200,7 +203,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
         // Note: $key is an md5 of the fieldname. The actual fieldname is
         // available in $multi_edit_columns_name[$key]
 
-        $file_to_insert = new PMA_File();
+        $file_to_insert = new PMA\libraries\File();
         $file_to_insert->checkTblChangeForm($key, $rownumber);
 
         $possibly_uploaded_val = $file_to_insert->getContent();
@@ -215,9 +218,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
                 . $mime_map[$column_name]['input_transformation'];
             if (is_file($filename)) {
                 include_once $filename;
-                $classname = PMA_getTransformationClassName(
-                    $mime_map[$column_name]['input_transformation']
-                );
+                $classname = PMA_getTransformationClassName($filename);
                 /** @var IOTransformationsPlugin $transformation_plugin */
                 $transformation_plugin = new $classname();
                 $transformation_options = PMA_Transformation_getOptions(
@@ -243,7 +244,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
         }
 
         if ($file_to_insert->isError()) {
-            $message .= $file_to_insert->getError();
+            $insert_errors[] = $file_to_insert->getError();
         }
         // delete $file_to_insert temporary variable
         $file_to_insert->cleanUp();
@@ -253,7 +254,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
             $current_value, $multi_edit_auto_increment,
             $rownumber, $multi_edit_columns_name, $multi_edit_columns_null,
             $multi_edit_columns_null_prev, $is_insert,
-            $using_key, $where_clause, $table
+            $using_key, $where_clause, $table, $multi_edit_funcs
         );
 
         $current_value_as_an_array = PMA_getCurrentValueAsAnArrayForMultipleEdit(
@@ -262,13 +263,15 @@ foreach ($loop_array as $rownumber => $where_clause) {
             $gis_from_wkb_functions, $func_optional_param, $func_no_param, $key
         );
 
-        list($query_values, $query_fields)
-            = PMA_getQueryValuesForInsertAndUpdateInMultipleEdit(
-                $multi_edit_columns_name, $multi_edit_columns_null, $current_value,
-                $multi_edit_columns_prev, $multi_edit_funcs, $is_insert,
-                $query_values, $query_fields, $current_value_as_an_array,
-                $value_sets, $key, $multi_edit_columns_null_prev
-            );
+        if (! isset($multi_edit_virtual) || ! isset($multi_edit_virtual[$key])) {
+            list($query_values, $query_fields)
+                = PMA_getQueryValuesForInsertAndUpdateInMultipleEdit(
+                    $multi_edit_columns_name, $multi_edit_columns_null, $current_value,
+                    $multi_edit_columns_prev, $multi_edit_funcs, $is_insert,
+                    $query_values, $query_fields, $current_value_as_an_array,
+                    $value_sets, $key, $multi_edit_columns_null_prev
+                );
+        }
         if (isset($multi_edit_columns_null[$key])) {
             $multi_edit_columns[$key] = null;
         }
@@ -284,18 +287,20 @@ foreach ($loop_array as $rownumber => $where_clause) {
             $value_sets[] = implode(', ', $query_values);
         } else {
             // build update query
-            $query[] = 'UPDATE ' . PMA_Util::backquote($GLOBALS['table'])
+            $query[] = 'UPDATE ' . PMA\libraries\Util::backquote($GLOBALS['table'])
                 . ' SET ' . implode(', ', $query_values)
                 . ' WHERE ' . $where_clause
                 . ($_REQUEST['clause_is_unique'] ? '' : ' LIMIT 1');
         }
     }
 } // end foreach ($loop_array as $where_clause)
-unset($multi_edit_columns_name, $multi_edit_columns_prev, $multi_edit_funcs,
+unset(
+    $multi_edit_columns_name, $multi_edit_columns_prev, $multi_edit_funcs,
     $multi_edit_columns_type, $multi_edit_columns_null, $func_no_param,
     $multi_edit_auto_increment, $current_value_as_an_array, $key, $current_value,
     $loop_array, $where_clause, $using_key,  $multi_edit_columns_null_prev,
-    $insert_fail);
+    $insert_fail
+);
 
 // Builds the sql query
 if ($is_insert && count($value_sets) > 0) {
@@ -304,7 +309,11 @@ if ($is_insert && count($value_sets) > 0) {
     // No change -> move back to the calling script
     //
     // Note: logic passes here for inline edit
-    $message = PMA_Message::success(__('No change'));
+    $message = PMA\libraries\Message::success(__('No change'));
+    // Avoid infinite recursion
+    if ($goto_include == 'tbl_replace.php') {
+        $goto_include = 'tbl_change.php';
+    }
     $active_page = $goto_include;
     include '' . PMA_securePath($goto_include);
     exit;
@@ -325,10 +334,14 @@ list ($url_params, $total_affected_rows, $last_messages, $warning_messages,
         = PMA_executeSqlQuery($url_params, $query);
 
 if ($is_insert && (count($value_sets) > 0 || $row_skipped)) {
-    $message = PMA_Message::getMessageForInsertedRows($total_affected_rows);
+    $message = PMA\libraries\Message::getMessageForInsertedRows(
+        $total_affected_rows
+    );
     $unsaved_values = array_values($unsaved_values);
 } else {
-    $message = PMA_Message::getMessageForAffectedRows($total_affected_rows);
+    $message = PMA\libraries\Message::getMessageForAffectedRows(
+        $total_affected_rows
+    );
 }
 if ($row_skipped) {
     $goto_include = 'tbl_change.php';
@@ -363,7 +376,7 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
      * transformed fields, if they were edited. After that, output the correct
      * link/transformed value and exit
      *
-     * Logic taken from libraries/DisplayResults.class.php
+     * Logic taken from libraries/DisplayResults.php
      */
 
     if (isset($_REQUEST['rel_fields_list']) && $_REQUEST['rel_fields_list'] != '') {
@@ -424,14 +437,14 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
     );
 
     /**Get the total row count of the table*/
-    $_table = new PMA_Table($_REQUEST['table'], $_REQUEST['db']);
+    $_table = new Table($_REQUEST['table'], $_REQUEST['db']);
     $extra_data['row_count'] = $_table->countRecords();
 
     $extra_data['sql_query']
-        = PMA_Util::getMessage($message, $GLOBALS['display_query']);
+        = PMA\libraries\Util::getMessage($message, $GLOBALS['display_query']);
 
-    $response = PMA_Response::getInstance();
-    $response->isSuccess($message->isSuccess());
+    $response = PMA\libraries\Response::getInstance();
+    $response->setRequestStatus($message->isSuccess());
     $response->addJSON('message', $message);
     $response->addJSON($extra_data);
     exit;
