@@ -27,9 +27,9 @@ textarea {
 
 
 body {
-<?php if (! empty($GLOBALS['cfg']['FontFamily'])) { ?>
+<?php if (! empty($GLOBALS['cfg']['FontFamily'])) : ?>
     font-family: <?php echo $GLOBALS['cfg']['FontFamily']; ?>;
-<?php } ?>
+<?php endif; ?>
     padding: 0;
     margin: 0;
     margin-<?php echo $left; ?>: 240px;
@@ -45,15 +45,14 @@ body#loginform {
     margin: 0 .5em;
 }
 
-<?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) { ?>
+<?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) : ?>
     textarea,
     tt,
     pre,
     code {
     font-family: <?php echo $GLOBALS['cfg']['FontFamilyFixed']; ?>;
     }
-    <?php
-} ?>
+<?php endif; ?>
 
 
 h1 {
@@ -608,13 +607,12 @@ tr:last-child td.condition {
     border-width: 0 1px 1px 1px;
 }
 
-<?php if ($GLOBALS['text_dir'] === 'ltr') { ?>
+<?php if ($GLOBALS['text_dir'] === 'ltr') : ?>
     /* for first th which must have right border set (ltr only) */
     .before-condition {
     border-right: 1px solid <?php echo $GLOBALS['cfg']['BrowseMarkerBackground']; ?>;
     }
-    <?php
-} ?>
+<?php endif; ?>
 
 /**
  * cells with the value NULL
@@ -638,12 +636,11 @@ table [class=value] {
 }
 
 
-<?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) { ?>
+<?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) : ?>
     .value {
     font-family: <?php echo $GLOBALS['cfg']['FontFamilyFixed']; ?>;
     }
-    <?php
-} ?>
+<?php endif; ?>
 .attention {
     color: red;
     font-weight: bold;
@@ -717,16 +714,14 @@ div.error {
     margin: .5em 0 0.5em;
     border: 1px solid;
     background-repeat: no-repeat;
-    <?php
-    if ($GLOBALS['text_dir'] === 'ltr') { ?>
+    <?php if ($GLOBALS['text_dir'] === 'ltr') : ?>
         background-position: 10px 50%;
         padding: 10px 10px 10px 10px;
-        <?php
-    } else { ?>
+    <?php else : ?>
         background-position: 99% 50%;
         padding: 10px 35px 10px 10px;
         <?php
-    } ?>
+    endif; ?>
 
     -moz-border-radius: 5px;
     -webkit-border-radius: 5px;
@@ -1515,16 +1510,13 @@ p.notice {
     margin: 1.5em 0;
     border: 1px solid #000;
     background-repeat: no-repeat;
-    <?php
-    if ($GLOBALS['text_dir'] === 'ltr') { ?>
+    <?php if ($GLOBALS['text_dir'] === 'ltr') : ?>
         background-position: 10px 50%;
         padding: 10px 10px 10px 25px;
-        <?php
-    } else { ?>
+    <?php else : ?>
         background-position: 99% 50%;
         padding: 25px 10px 10px 10px
-        <?php
-    } ?>
+    <?php endif; ?>
     -moz-border-radius: 5px;
     -webkit-border-radius: 5px;
     border-radius: 5px;
@@ -1595,32 +1587,25 @@ div#profilingchart {
 #sectionlinks a,
 .buttonlinks a,
 a.button {
-    font-size: .88em;
     font-weight: bold;
     text-shadow: 0 1px 0 #fff;
     line-height: 35px;
     margin-<?php echo $left; ?>: 7px;
     border: 1px solid #aaa;
-    padding: 5px 10px;
-    color: #111;
+    padding: 3px 7px;
+    color: #111 !important;
     text-decoration: none;
     background: #ddd;
     white-space: nowrap;
     border-radius: 20px;
     -webkit-border-radius: 20px;
     -moz-border-radius: 20px;
-    box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 2px rgba(0,0,0,.5);
-    /*
-    -webkit-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 2px rgba(0,0,0,.5);
-    -moz-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 2px rgba(0,0,0,.5);
-    text-shadow: #fff 0 1px 0;
-    */
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'cccccc'); ?>
+    <?php echo $_SESSION['PMA_Theme']->getCssGradient('f8f8f8', 'd8d8d8'); ?>
 }
 #sectionlinks a:hover,
 .buttonlinks a:hover,
 a.button:hover {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('cccccc', 'dddddd'); ?>
+    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'dddddd'); ?>
 }
 
 div#sqlquerycontainer {
@@ -1801,6 +1786,16 @@ label.desc sup {
     position: absolute;
 }
 
+code.php {
+    display: block;
+    padding-left: 1em;
+    margin-top: 0;
+    margin-bottom: 0;
+    max-height: 10em;
+    overflow: auto;
+    direction: ltr;
+}
+
 code.sql,
 div.sqlvalidate {
     display: block;
@@ -1814,7 +1809,14 @@ div.sqlvalidate {
 
 .result_query div.sqlOuter {
     background: <?php echo $GLOBALS['cfg']['BgOne']; ?>;
-    padding: 1em;
+}
+
+.result_query .success, .result_query .error {
+    margin-bottom: 0;
+    border-bottom: none !important;
+    border-bottom-left-radius: 0;
+    border-bottom-right-radius: 0;
+    padding-bottom: 5px;
 }
 
 #PMA_slidingMessage code.sql,
@@ -2881,7 +2883,8 @@ fieldset .disabled-field td {
 }
 
 .cEdit .edit_box {
-    overflow: hidden;
+    overflow-x: hidden;
+    overflow-y: scroll;
     padding: 0;
     margin: 0;
 }
@@ -3536,4 +3539,4 @@ body .ui-dialog .ui-dialog-title {
 body .ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
     float: <?php echo $right; ?>;
 }
-/* end of styles for jQuery-ui to support rtl languages */
\ No newline at end of file
+/* end of styles for jQuery-ui to support rtl languages */
