@@ -11,12 +11,21 @@
  */
 define('PMA_MINIMUM_COMMON', true);
 require_once './libraries/common.inc.php';
+/**
+ * JavaScript escaping.
+ */
+require_once './libraries/js_escape.lib.php';
 
-if (! PMA_isValid($_GET['url'])
-    || ! preg_match('/^https?:\/\/[^\n\r]*$/', $_GET['url'])
-    || ! PMA_isAllowedDomain($_GET['url'])
+// Only output the http headers
+$response = PMA\libraries\Response::getInstance();
+$response->getHeader()->sendHttpHeaders();
+$response->disable();
+
+if (! PMA_isValid($_REQUEST['url'])
+    || ! preg_match('/^https:\/\/[^\n\r]*$/', $_REQUEST['url'])
+    || ! PMA_isAllowedDomain($_REQUEST['url'])
 ) {
-    header('Location: ' . $cfg['PmaAbsoluteUri']);
+    PMA_sendHeaderLocation('./');
 } else {
     // JavaScript redirection is necessary. Because if header() is used
     //  then web browser sometimes does not change the HTTP_REFERER
@@ -24,11 +33,11 @@ if (! PMA_isValid($_GET['url'])
     //  external site.
     echo "<script type='text/javascript'>
             window.onload=function(){
-                window.location='" . htmlspecialchars($_GET['url']) . "';
+                window.location='" , PMA_escapeJsString($_REQUEST['url']) , "';
             }
         </script>";
     // Display redirecting msg on screen.
-    printf(__('Taking you to %s.'), htmlspecialchars($_GET['url']));
+    // Do not display the value of $_REQUEST['url'] to avoid showing injected content
+    echo __('Taking you to the target site.');
 }
 die();
-?>
