@@ -7,10 +7,14 @@
  */
 
 // Sets up the session
-define('PMA_MINIMUM_COMMON', true);
+use PMA\libraries\VersionInformation;
+
+$_GET['ajax_request'] = 'true';
+
 require_once 'libraries/common.inc.php';
-require_once 'libraries/Util.class.php';
-require_once 'libraries/VersionInformation.php';
+
+// Disabling standard response.
+PMA\libraries\Response::getInstance()->disable();
 
 // Always send the correct headers
 PMA_headerJSON();
